abacusai.indexing_config — AbacusAI documentation

# abacusai.indexing_config

## Classes

`AbstractApiClass` |
`IndexingConfig` | The indexing config for a Feature Group

## Module Contents

class abacusai.indexing_config.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.indexing_config.IndexingConfig(client, primaryKey=None, updateTimestampKey=None, lookupKeys=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  The indexing config for a Feature Group

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - primaryKey (str) – A single key index

    - updateTimestampKey (str) – The primary timestamp feature

    - lookupKeys (list[str]) – A multi-key index. Cannot be used in conjuction with primary key.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict